==> phoenix_widgets-1.13.1.tar.gz: lib/phoenix_navigation_card.dart <==
import 'package:flutter/material.dart';

class PhoenixNavigationCard extends StatelessWidget {
  const PhoenixNavigationCard({
    Key? key,
    this.width,
    this.padding,
    this.callback,
    this.backgroundColor,
    this.icon,
    this.icColor,
    this.icHeight,
    this.icWidth,
    required this.title,
    required this.description,
    required this.navigationText,
    this.icBtnBackgroundColor,
    this.icBtnColor,
    this.icBtnSize,
  }) : super(key: key);

  /// Decoration parameter
  final double? width;
  final EdgeInsets? padding;
  final VoidCallback? callback;
  final Color? backgroundColor;
  final double borderRadius = 4;
  final double? icHeight;
  final double? icWidth;
  final Color? icColor;
  final Color? icBtnBackgroundColor;
  final Color? icBtnColor;
  final double? icBtnSize;

  /// Widget inside card
  final Widget? icon;
  final Widget title;
  final Widget description;
  final Widget navigationText;

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.all(16.0),
      child: InkWell(
        onTap: () {
          if (callback != null) {
            callback!();
          } else {
            Navigator.of(context).pop();
          }
        },
        child: Container(
          width: width ?? double.maxFinite,
          padding: padding ?? const EdgeInsets.only(top: 16, bottom: 16),
          decoration: BoxDecoration(
            color: backgroundColor ?? const Color(0x1AC9B47D),
            borderRadius: BorderRadius.all(Radius.circular(borderRadius)),
          ),
          child: ClipRRect(
            borderRadius: BorderRadius.circular(borderRadius),
            child: Material(
              color: Colors.transparent,
              child: Column(
                mainAxisSize: MainAxisSize.min,
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  ListTile(
                    leading: Container(
                      height: icHeight ?? 46,
                      width: icWidth ?? 46,
                      color: icColor ?? Colors.transparent,
                      child: icon,
                    ),
                    title: title,
                    subtitle: description,
                  ),
                  Row(
                    mainAxisSize: MainAxisSize.min,
                    children: [
                      const SizedBox(width: 78),
                      navigationText,
                      const SizedBox(width: 8),
                      CircleAvatar(
                        backgroundColor:
                            icBtnBackgroundColor ?? const Color(0x10C9B47D),
                        radius: 12,
                        child: Icon(
                          Icons.keyboard_arrow_right_rounded,
                          color: icBtnColor ?? const Color(0xFFC9B47D),
                          size: icBtnSize ?? 16,
                        ),
                      ),
                    ],
                  ),
                ],
              ),
            ),
          ),
        ),
      ),
    );
  }
}

==> phoenix_widgets-1.17.4.tar.gz: lib/phoenix_navigation_card.dart <==
import 'package:flutter/material.dart';

class PhoenixNavigationCard extends StatelessWidget {
  const PhoenixNavigationCard({
    Key? key,
    this.width,
    this.padding,
    this.callback,
    this.backgroundColor,
    this.icon,
    this.icColor,
    this.icHeight,
    this.icWidth,
    required this.title,
    required this.description,
    this.navigationText,
    this.isVisible = true,
    this.icBtnBackgroundColor,
    this.icBtnColor,
    this.icBtnSize,
  }) : super(key: key);

  /// Decoration parameter
  final double? width;
  final EdgeInsets? padding;
  final VoidCallback? callback;
  final Color? backgroundColor;
  final double borderRadius = 4;
  final double? icHeight;
  final double? icWidth;
  final Color? icColor;
  final Color? icBtnBackgroundColor;
  final Color? icBtnColor;
  final double? icBtnSize;

  /// Widget inside card
  final Widget? icon;
  final Widget title;
  final Widget description;
  final Widget? navigationText;
  final bool isVisible;

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.all(16.0),
      child: InkWell(
        onTap: () {
          if (callback != null) {
            callback!();
          } else {
            Navigator.of(context).pop();
          }
        },
        child: Container(
          width: width ?? double.maxFinite,
          padding: padding ?? const EdgeInsets.only(top: 16, bottom: 16),
          decoration: BoxDecoration(
            color: backgroundColor ?? const Color(0x1AC9B47D),
            borderRadius: BorderRadius.all(Radius.circular(borderRadius)),
          ),
          child: ClipRRect(
            borderRadius: BorderRadius.circular(borderRadius),
            child: Material(
              color: Colors.transparent,
              child: Column(
                mainAxisSize: MainAxisSize.min,
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  ListTile(
                    leading: Container(
                      height: icHeight ?? 46,
                      width: icWidth ?? 46,
                      color: icColor ?? Colors.transparent,
                      child: icon,
                    ),
                    title: title,
                    subtitle: description,
                  ),
                  Visibility(
                    visible: isVisible,
                    child: Row(
                      mainAxisSize: MainAxisSize.min,
                      children: [
                        const SizedBox(width: 78),
                        navigationText ?? const Text('Click Me'),
                        const SizedBox(width: 8),
                        CircleAvatar(
                          backgroundColor:
                              icBtnBackgroundColor ?? const Color(0x10C9B47D),
                          radius: 12,
                          child: Icon(
                            Icons.keyboard_arrow_right_rounded,
                            color: icBtnColor ?? const Color(0xFFC9B47D),
                            size: icBtnSize ?? 16,
                          ),
                        ),
                      ],
                    ),
                  ),
                ],
              ),
            ),
          ),
        ),
      ),
    );
  }
}
